@@ -22,18 +22,17 @@
 
 #include <string.h>
 #include <unistd.h>
-#include "gtk24backports.h"
+#include <glib/gi18n.h>
 #include "kz-entry-action.h"
 #include "gtk-utils.h"
 #include "glib-utils.h"
-#include "intl.h"
 #include "kazehakase.h"
 #include "kz-window.h"
 #include "kz-tab-label.h"
 #include "kz-actions-download.h"
-#include "mozilla-prefs.h"
-#include "kz-mozembed.h"
+#include "kz-embed.h"
 #include "kz-favicon.h"
+#include "kz-xml.h"
 
 #define KZ_ACTIONS_POPUP_LANGUAGE_KEY "KzActionsPopup::Language"
 #define KZ_ACTIONS_POPUP_TAB_KEY "KzActionsPopup::Tab"
@@ -53,17 +52,12 @@ typedef enum {
 
 typedef struct
 {
-	KzMozEmbed *kzembed;
+	KzEmbed *kzembed;
 	gchar *filename;  /* file name for edior */
 	gpointer element; /* pointer indicated textarea */
 } EditorInfo;
 
-static const gchar *label_color[] =
-{
-	"#000000",
-	"#ff0000",
-	"#22aa44",
-};
+static gchar *label_color[KZ_TAB_LABEL_N_STATE];
 
 static void kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu);
 
@@ -100,8 +94,8 @@ open_location (GtkAction *action, KzWindow *kz, LocationType location, WindowTyp
 		kz_window_load_url(kz, uri);
 		break;
 	case NEW_TAB:
-		kz_window_open_new_tab_with_parent (kz, uri,
-						    KZ_WINDOW_CURRENT_PAGE(kz));
+		kz_window_open_new_tab_with_parent(kz, uri,
+						   KZ_WINDOW_CURRENT_PAGE(kz));
 		break;
 	case NEW_WINDOW:
 	{
@@ -214,8 +208,11 @@ act_popup_open_frame (GtkAction *action, KzWindow *kz)
 }
 
 static void
-cb_embed_changed (GtkMozEmbed *embed, EditorInfo *einfo)
+cb_embed_changed (KzEmbed *embed, EditorInfo *einfo)
 {
+	g_return_if_fail(KZ_IS_EMBED(embed));
+	g_return_if_fail(einfo);
+
 	g_signal_handlers_disconnect_by_func(G_OBJECT(embed),
 			 		     G_CALLBACK(cb_embed_changed),
 					     einfo);
@@ -238,9 +235,8 @@ cb_editor_exit (GPid pid, gint status, gpointer data)
 	EditorInfo *einfo;
 	
 	/* close editor process */
-#if (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION > 3)
 	g_spawn_close_pid(pid);
-#endif
+
 	if (!data) return;
 
 	einfo = (EditorInfo*)data;
@@ -259,11 +255,11 @@ cb_editor_exit (GPid pid, gint status, gpointer data)
 		/* set text into textarea */
 		if (ret)
 		{
-			if (KZ_IS_MOZ_EMBED(einfo->kzembed) && einfo->element)
+			if (KZ_EMBED(einfo->kzembed) && einfo->element)
 			{
-				kz_moz_embed_set_text_into_textarea(einfo->kzembed,
-								    einfo->element,
-								    text);
+				kz_embed_set_text_into_textarea(einfo->kzembed,
+								einfo->element,
+								text);
 			}
 			g_free(text);
 		}
@@ -299,7 +295,7 @@ act_popup_launch_editor (GtkAction *action, KzWindow *kz)
 	
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 	widget = KZ_WINDOW_CURRENT_PAGE(kz);
-	g_return_if_fail(KZ_IS_MOZ_EMBED(widget));
+	g_return_if_fail(KZ_EMBED(widget));
 
 	event = kz_window_get_mouse_event_info(kz);
 	g_return_if_fail(event);
@@ -311,10 +307,10 @@ act_popup_launch_editor (GtkAction *action, KzWindow *kz)
 	if (event->cinfo.context & KZ_CONTEXT_TEXTAREA)
 	{
 		einfo = g_new0(EditorInfo, 1);
-		einfo->kzembed  = g_object_ref(KZ_MOZ_EMBED(widget));
+		einfo->kzembed  = g_object_ref(KZ_EMBED(widget));
 		einfo->element  = event->cinfo.element;
-		text = kz_moz_embed_get_text_from_textarea(KZ_MOZ_EMBED(widget),
-							   einfo->element);
+		text = kz_embed_get_text_from_textarea(KZ_EMBED(widget),
+						       einfo->element);
 		/* text in textare store in temporary file */
 		if (text)
 		{
@@ -334,7 +330,7 @@ act_popup_launch_editor (GtkAction *action, KzWindow *kz)
 	}
 	
 	/* */
-	g_signal_connect(G_OBJECT(widget), "net_start",
+	g_signal_connect(G_OBJECT(widget), "kz-net-start",
 			 G_CALLBACK(cb_embed_changed), einfo);
 	g_signal_connect(G_OBJECT(widget), "destroy",
 			 G_CALLBACK(cb_embed_changed), einfo);
@@ -374,8 +370,8 @@ static void
 cb_tablist_menuitem_activate (GtkWidget *menuitem, KzWindow *kz)
 {
 	gint page_num;
-	GtkWidget *widget = g_object_get_data (G_OBJECT(menuitem),
-					       KZ_ACTIONS_POPUP_TAB_KEY);
+	GtkWidget *widget = g_object_get_data(G_OBJECT(menuitem),
+					      KZ_ACTIONS_POPUP_TAB_KEY);
 
 	page_num = gtk_notebook_page_num(GTK_NOTEBOOK(kz->notebook),
 					 GTK_WIDGET(widget));
@@ -388,13 +384,10 @@ static void
 act_popup_tab_list (GtkAction *action, KzWindow *kz)
 {
 	GtkWidget *popup_menu = NULL;
-	gchar path[64] = {0};
 	GList *children, *node;
 
-	g_snprintf(path, sizeof(path), "/TabListPopup%s",
-		   kz_ui_level_to_suffix(kz_ui_level()));
-
-	popup_menu = gtk_ui_manager_get_widget(kz->menu_merge, path);
+	popup_menu = gtk_ui_manager_get_widget(kz->menu_merge,
+					       "/TabListPopup");
 	if (!popup_menu) return;
 
 	/* remove previous menu item */
@@ -407,7 +400,7 @@ act_popup_tab_list (GtkAction *action, KzWindow *kz)
 	}
 	g_list_free(children);
 
-	kz_actions_popup_append_tablist_menuitem (kz, popup_menu);
+	kz_actions_popup_append_tablist_menuitem(kz, popup_menu);
 	
 	g_signal_connect(G_OBJECT(popup_menu), "hide",
 			 G_CALLBACK(cb_popup_menu_hide), kz);
@@ -470,10 +463,10 @@ kz_actions_popup_create_group (KzWindow *kz, GtkAccelGroup *accel_group)
 
 	gtk_action_group_set_translation_domain(action_group, NULL);
 
-	gtk_action_group_add_actions (action_group,
-				      kz_actions_popup,
-				      kz_actions_popup_len,
-				      kz);
+	gtk_action_group_add_actions(action_group,
+				     kz_actions_popup,
+				     kz_actions_popup_len,
+				     kz);
 
 	action_list = gtk_action_group_list_actions(action_group);
 	
@@ -500,19 +493,34 @@ cb_popup_destroy (GtkWidget *extra_menu)
 	return;
 }
 
+static gboolean 
+cb_encoding_menuitem_destroy (GtkWidget *menuitem, gchar *encoding)
+{
+	g_return_val_if_fail (GTK_CHECK_MENU_ITEM(menuitem), FALSE);
+	
+	if (encoding)
+		g_free(encoding);
+	
+	g_object_set_data(G_OBJECT(menuitem), 
+			  KZ_ACTIONS_POPUP_LANGUAGE_KEY,
+			  NULL);
+	
+	return FALSE;
+}
+
 static void
 cb_encoding_menuitem_activate (GtkWidget *menuitem, KzWindow *kz)
 {
 	GtkWidget *widget = KZ_WINDOW_CURRENT_PAGE(kz);
 
-	if (GTK_CHECK_MENU_ITEM(menuitem)->active && KZ_IS_MOZ_EMBED(widget))
+	if (GTK_CHECK_MENU_ITEM(menuitem)->active && KZ_EMBED(widget))
 	{
-		const gchar* code = g_object_get_data (G_OBJECT(menuitem),
-						       KZ_ACTIONS_POPUP_LANGUAGE_KEY);
-
+		const gchar* code
+			= g_object_get_data(G_OBJECT(menuitem),
+					    KZ_ACTIONS_POPUP_LANGUAGE_KEY);
 		GtkAction *action;
 
-		kz_moz_embed_set_encoding(KZ_MOZ_EMBED(widget), code);
+		kz_embed_set_encoding(KZ_EMBED(widget), code);
 
 		action = gtk_action_group_get_action(kz->actions, "Reload");
 
@@ -521,86 +529,160 @@ cb_encoding_menuitem_activate (GtkWidget *menuitem, KzWindow *kz)
 	return;
 }
 
+static GtkWidget *
+create_lang_menu_item (KzWindow *kz, KzXMLNode *node,
+		       GSList **group, const gchar *current_encoding,
+		       gboolean forced)
+{
+	GtkWidget *menuitem = NULL;
+	const gchar *label;
+
+	if (!kz_xml_node_is_element(node)) return NULL;
+
+	label = kz_xml_node_get_attr(node, "label");
+	g_return_val_if_fail(label, NULL);
+
+	if (kz_xml_node_name_is(node, "group"))
+	{
+		GtkWidget *submenu;
+		KzXMLNode *child_node;
+
+		menuitem = gtk_menu_item_new_with_label(label);
+		submenu = gtk_menu_new();
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(menuitem), submenu);
+		gtk_widget_show(submenu);
+
+		for (child_node = kz_xml_node_first_child(node);
+		     child_node;
+		     child_node = kz_xml_node_next(child_node))
+		{
+			GtkWidget *child_menuitem;
+
+			child_menuitem = create_lang_menu_item
+				(kz, child_node, group,
+				 current_encoding, forced);
+			if (!child_menuitem) continue;
+
+			gtk_menu_shell_append(GTK_MENU_SHELL(submenu),
+					      child_menuitem);
+			gtk_widget_show(child_menuitem);
+		}
+	}
+	else if (kz_xml_node_name_is(node, "encoding"))
+	{
+		gchar *encoding;
+
+		encoding = g_strdup(kz_xml_node_get_attr(node, "name"));
+
+		menuitem = gtk_radio_menu_item_new_with_label(*group, _(label));
+		g_object_set_data(G_OBJECT(menuitem),
+				  KZ_ACTIONS_POPUP_LANGUAGE_KEY,
+				  (gpointer) encoding);
+		g_signal_connect(G_OBJECT(menuitem), "activate",
+				 G_CALLBACK(cb_encoding_menuitem_activate), kz);
+		g_signal_connect(G_OBJECT(menuitem), "destroy",
+				 G_CALLBACK(cb_encoding_menuitem_destroy), encoding);
+
+		if (forced && current_encoding &&
+		    !strcmp(current_encoding, encoding))
+		{
+			gtk_check_menu_item_set_active
+				(GTK_CHECK_MENU_ITEM(menuitem),
+				 TRUE);
+		}
+		*group = gtk_radio_menu_item_get_group
+				(GTK_RADIO_MENU_ITEM(menuitem));
+	}
+	else
+	{
+		/* warning? */
+	}
+
+	return menuitem;
+}
+
 static void
-kz_actions_popup_append_encoding_menuitem (KzWindow *kz, GtkMenuItem *encoding_menu)
+kz_actions_popup_append_encoding_menuitem (KzWindow *kz,
+					   GtkMenuItem *encoding_menu)
 {
 	GtkWidget *encoding_submenu;
+	GtkWidget *menuitem;
+	GSList *group = NULL;
+	GtkWidget *page = KZ_WINDOW_CURRENT_PAGE(kz);
+	gchar *current_encoding = NULL;
+	gboolean forced = FALSE;
+	KzXML *xml;
+	KzXMLNode *node;
 
-	if (!popup_menu_table) {
+	if (!popup_menu_table)
+	{
 		popup_menu_table = g_hash_table_new(g_direct_hash,
 						    g_direct_equal);
 	}
 
 	encoding_submenu = g_hash_table_lookup(popup_menu_table, encoding_menu);
-	if (!encoding_submenu) 
-	{
-		GtkWidget *menuitem;
-		GSList *group = NULL;
-		GtkWidget *page = KZ_WINDOW_CURRENT_PAGE(kz);
-		guint  i;
-		gchar *current_encoding = NULL;
-		gboolean forced = FALSE;
-		
-                /* append encodings menuitem */
-		encoding_submenu = gtk_menu_new();
-		
-                /* get current charset */
-		if(KZ_IS_MOZ_EMBED(page))
-		{
-			kz_moz_embed_get_encoding (KZ_MOZ_EMBED(page), &current_encoding, &forced);
-		}
-		
-		menuitem = gtk_radio_menu_item_new_with_label (group,_("Auto"));
-		if(!forced) {
-			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem),
-							TRUE);
-		}
-		
-		group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem));
-		g_object_set_data (G_OBJECT (menuitem), KZ_ACTIONS_POPUP_LANGUAGE_KEY, "");
-		
-		g_signal_connect (G_OBJECT(menuitem), "activate",
-				  G_CALLBACK (cb_encoding_menuitem_activate), kz);
-		
-		gtk_menu_shell_append (GTK_MENU_SHELL(encoding_submenu), menuitem);
-		gtk_widget_show (menuitem);
+	if (encoding_submenu) return;
 
-                /* separator */
-		menuitem = gtk_separator_menu_item_new();
-		gtk_menu_shell_append(GTK_MENU_SHELL(encoding_submenu), menuitem);
-		gtk_widget_show(menuitem);
-	
-		for (i = 0; i < n_languages; ++i)
-		{
-			menuitem = gtk_radio_menu_item_new_with_label (group,_(languages[i].name));
-			
-			if (forced && !strcmp(current_encoding, languages[i].code))
-			{
-				gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem),
-								TRUE);
-			}
-			
-			group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem));
-			
-			g_object_set_data (G_OBJECT (menuitem), KZ_ACTIONS_POPUP_LANGUAGE_KEY,
-					   (gchar*)languages[i].code);
-			
-			g_signal_connect (G_OBJECT(menuitem), "activate",
-					  G_CALLBACK (cb_encoding_menuitem_activate), kz);
+	/* append encodings menuitem */
+	encoding_submenu = gtk_menu_new();
 		
-			gtk_menu_shell_append (GTK_MENU_SHELL(encoding_submenu), menuitem);
-			gtk_widget_show (menuitem);
-		}
-		gtk_menu_item_set_submenu(GTK_MENU_ITEM(encoding_menu), encoding_submenu);
-		
-		g_free(current_encoding);
-		
-                /* reference */
-		g_hash_table_insert(popup_menu_table, encoding_menu, encoding_submenu);
-		g_signal_connect(G_OBJECT(encoding_menu), "destroy",
-				 G_CALLBACK(cb_popup_destroy), NULL);
+	/* get current charset */
+	if(KZ_EMBED(page))
+	{
+		kz_embed_get_encoding(KZ_EMBED(page),
+				      &current_encoding, &forced);
 	}
-	return;
+
+	menuitem = gtk_radio_menu_item_new_with_label(group, _("Auto"));
+	if(!forced) {
+		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem),
+					       TRUE);
+	}
+
+	group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(menuitem));
+	g_object_set_data(G_OBJECT(menuitem),
+			  KZ_ACTIONS_POPUP_LANGUAGE_KEY, "");
+
+	g_signal_connect(G_OBJECT(menuitem), "activate",
+			 G_CALLBACK(cb_encoding_menuitem_activate), kz);
+
+	gtk_menu_shell_append(GTK_MENU_SHELL(encoding_submenu), menuitem);
+	gtk_widget_show(menuitem);
+
+	/* separator */
+	menuitem = gtk_separator_menu_item_new();
+	gtk_menu_shell_append(GTK_MENU_SHELL(encoding_submenu), menuitem);
+	gtk_widget_show(menuitem);
+
+	xml = kz_xml_new();
+	kz_xml_load(xml, KZ_SYSCONFDIR "/mozilla/encodings.xml");
+	node = kz_xml_get_root_element(xml);
+	if (node && kz_xml_node_name_is(node, "encodings"))
+	{
+		node = kz_xml_node_first_child(node);
+		for (; node; node = kz_xml_node_next(node))
+		{
+			menuitem = create_lang_menu_item(kz, node, &group,
+							 current_encoding,
+							 forced);
+			if (!menuitem) continue;
+
+			gtk_menu_shell_append(GTK_MENU_SHELL(encoding_submenu),
+					      menuitem);
+			gtk_widget_show(menuitem);
+		}
+	}
+	g_object_unref(G_OBJECT(xml));
+
+	gtk_menu_item_set_submenu(GTK_MENU_ITEM(encoding_menu),
+				  encoding_submenu);
+
+	g_free(current_encoding);
+
+	/* reference */
+	g_hash_table_insert(popup_menu_table, encoding_menu, encoding_submenu);
+	g_signal_connect(G_OBJECT(encoding_menu), "destroy",
+			 G_CALLBACK(cb_popup_destroy), NULL);
 }
 
 
@@ -608,11 +690,38 @@ static void
 kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 {
 	gint i;
-	const gint num = gtkutil_notebook_get_n_pages(GTK_NOTEBOOK(kz->notebook));
+	const gint num = gtk_notebook_get_n_pages(GTK_NOTEBOOK(kz->notebook));
 	GtkWidget *tablist_submenu;
 	GtkWidget *page;
 	gint current_page_num;
 	KzFavicon *kzfav;
+	gchar *color = NULL;
+
+	/* label color */
+	color = KZ_CONF_GET_STR("Tab" , "normal_color");
+	if (!color)
+		color = g_strdup("#000000");
+
+	if (label_color[KZ_TAB_LABEL_STATE_NORMAL])
+		g_free(label_color[KZ_TAB_LABEL_STATE_NORMAL]);
+	label_color[KZ_TAB_LABEL_STATE_NORMAL] = g_strdup(color);
+	g_free(color);
+
+	color = KZ_CONF_GET_STR("Tab" , "loading_color");
+	if (!color)
+		color = g_strdup("#ff0000");
+	if (label_color[KZ_TAB_LABEL_STATE_LOADING])
+		g_free(label_color[KZ_TAB_LABEL_STATE_LOADING]);
+	label_color[KZ_TAB_LABEL_STATE_LOADING] = g_strdup(color);
+	g_free(color);
+
+	color = KZ_CONF_GET_STR("Tab" , "loaded_color");
+	if (!color)
+		color = g_strdup("#22aa44");
+	if (label_color[KZ_TAB_LABEL_STATE_LOADED])
+		g_free(label_color[KZ_TAB_LABEL_STATE_LOADED]);
+	label_color[KZ_TAB_LABEL_STATE_LOADED] = g_strdup(color);
+	g_free(color);
 
 	kzfav = kz_favicon_get_instance();
 
@@ -645,9 +754,10 @@ kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 
 	for (i = 0; i < num; i++)
 	{
-		KzMozEmbed *kzembed = KZ_MOZ_EMBED(KZ_WINDOW_NTH_PAGE(kz, i));
+		KzEmbed *kzembed = KZ_EMBED(KZ_WINDOW_NTH_PAGE(kz, i));
 		GtkWidget *favicon;
-		if (KZ_IS_MOZ_EMBED(kzembed))
+
+		if (KZ_EMBED(kzembed))
 		{
 			gchar *title, *escaped, *markup_title;
 			GtkWidget *menuitem;
@@ -656,10 +766,10 @@ kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 			
 			tab = kz_window_get_tab_label(kz, GTK_WIDGET(kzembed));
 			state = kz_tab_label_get_state(KZ_TAB_LABEL(tab));
-			title = kz_moz_embed_ensure_title(kzembed);
+			title = kz_embed_ensure_title(kzembed);
 			escaped = g_markup_escape_text(title,
 						       strlen(title));
-			menuitem = gtk_image_menu_item_new_with_label (title);
+			menuitem = gtk_image_menu_item_new_with_label(title);
 
 			if (i == current_page_num)
 			{
@@ -680,7 +790,7 @@ kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 			
 			/* favicon */
 			favicon = kz_favicon_get_widget(kzfav,
-							kz_moz_embed_get_location(kzembed),
+							kz_embed_get_location(kzembed),
 							KZ_ICON_SIZE_BOOKMARK_MENU);
 			if (favicon)
 			{
@@ -689,12 +799,12 @@ kz_actions_popup_append_tablist_menuitem (KzWindow *kz, GtkWidget *tablist_menu)
 							      favicon);
 			}
 
-			g_object_set_data (G_OBJECT (menuitem), KZ_ACTIONS_POPUP_TAB_KEY, kzembed);
+			g_object_set_data (G_OBJECT(menuitem), KZ_ACTIONS_POPUP_TAB_KEY, kzembed);
 
-			g_signal_connect (G_OBJECT(menuitem), "activate",
-					  G_CALLBACK(cb_tablist_menuitem_activate), kz);
-			gtk_menu_shell_append (GTK_MENU_SHELL(tablist_submenu), menuitem);
-			gtk_widget_show (menuitem);
+			g_signal_connect(G_OBJECT(menuitem), "activate",
+					 G_CALLBACK(cb_tablist_menuitem_activate), kz);
+			gtk_menu_shell_append(GTK_MENU_SHELL(tablist_submenu), menuitem);
+			gtk_widget_show(menuitem);
 			g_free(title);
 		}
 	}
@@ -750,24 +860,18 @@ kz_actions_popup_menu_modal (KzWindow *kz, guint button, guint time)
 	if (is_doc)
 	{
 		if (is_frame)
-			g_snprintf(path, sizeof(path), "/DocumentPopupinFrame%s",
-				   kz_ui_level_to_suffix(kz_ui_level()));
+			g_snprintf(path, sizeof(path), "/DocumentPopupinFrame");
 		else
-			g_snprintf(path, sizeof(path), "/DocumentPopup%s",
-				   kz_ui_level_to_suffix(kz_ui_level()));
+			g_snprintf(path, sizeof(path), "/DocumentPopup");
 	}
 	if (is_link && is_image)
-		g_snprintf(path, sizeof(path), "/LinkImagePopup%s",
-			   kz_ui_level_to_suffix(kz_ui_level()));
+		g_snprintf(path, sizeof(path), "/LinkImagePopup");
 	else if (is_link)
-		g_snprintf(path, sizeof(path), "/LinkPopup%s",
-			   kz_ui_level_to_suffix(kz_ui_level()));
+		g_snprintf(path, sizeof(path), "/LinkPopup");
 	else if (is_image)
-		g_snprintf(path, sizeof(path), "/ImagePopup%s",
-			   kz_ui_level_to_suffix(kz_ui_level()));
+		g_snprintf(path, sizeof(path), "/ImagePopup");
 	else if (is_input)
-		g_snprintf(path, sizeof(path), "/InputPopup%s",
-			   kz_ui_level_to_suffix(kz_ui_level()));
+		g_snprintf(path, sizeof(path), "/InputPopup");
 
 	if (!*path) return;
 
@@ -779,20 +883,23 @@ kz_actions_popup_menu_modal (KzWindow *kz, guint button, guint time)
 	}
 
         /* add encoding menu */
-	g_snprintf(extra_menu_path, sizeof(extra_menu_path), "%s/EncodingMenu", path);
+	g_snprintf(extra_menu_path,
+		   sizeof(extra_menu_path), "%s/EncodingMenu", path);
 
 	extra_menu = GET_MENU(kz, extra_menu_path);
 	if(extra_menu) 
 	{
-		kz_actions_popup_append_encoding_menuitem(kz, GTK_MENU_ITEM(extra_menu));
+		kz_actions_popup_append_encoding_menuitem
+			(kz, GTK_MENU_ITEM(extra_menu));
 	}
 
         /* add tablist */
-	g_snprintf(extra_menu_path, sizeof(extra_menu_path), "%s/TabList", path);
+	g_snprintf(extra_menu_path,
+		   sizeof(extra_menu_path), "%s/TabList", path);
 	extra_menu = GET_MENU(kz, extra_menu_path);
 	if(extra_menu) 
 	{
-		kz_actions_popup_append_tablist_menuitem (kz, extra_menu);
+		kz_actions_popup_append_tablist_menuitem(kz, extra_menu);
 	}
 
 	g_signal_connect(G_OBJECT(popup_menu), "hide",
