@@ -223,6 +223,23 @@ act_tab_toggle_lock (GtkAction *action, KzWindow *kz)
 		kz_tab_label_set_lock(kztab, FALSE);
 }
 
+static void
+act_tab_toggle_auto_refresh (GtkAction *action, KzWindow *kz)
+{
+	KzTabLabel *kztab;
+
+	g_return_if_fail(GTK_IS_TOGGLE_ACTION(action));
+	g_return_if_fail(KZ_IS_WINDOW(kz));
+
+	kztab = g_object_get_qdata(G_OBJECT(kz), kztab_quark);
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+
+	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION(action)))
+		kz_tab_label_set_auto_refresh(kztab, TRUE);
+	else
+		kz_tab_label_set_auto_refresh(kztab, FALSE);
+}
+
 static void
 act_tab_copy_tab (GtkAction *action, KzWindow *kz)
 {
@@ -281,6 +298,8 @@ GtkToggleActionEntry kz_toggle_actions_tab[] =
 {
 	{"TabToggleLock",     KZ_STOCK_ANCHOR, N_("Tab Loc_k"),
 	 NULL, NULL, G_CALLBACK(act_tab_toggle_lock), FALSE},
+	{"TabAutoRefresh",     KZ_STOCK_ANCHOR, N_("Refresh Tab _automatically"),
+	 NULL, NULL, G_CALLBACK(act_tab_toggle_auto_refresh), FALSE},
 };
 const gint kz_actions_tab_len = G_N_ELEMENTS(kz_actions_tab);
 const gint kz_toggle_actions_tab_len = G_N_ELEMENTS(kz_toggle_actions_tab);
@@ -333,7 +352,7 @@ set_popup_menu_sensitive (KzTabLabel *kztab)
 	KzWindow *kz;
 	GtkAction *action;
 	gint pos, num;
-	gboolean lock;
+	gboolean lock, auto_refresh;
 
 	g_return_if_fail(kztab);
 
@@ -366,6 +385,11 @@ set_popup_menu_sensitive (KzTabLabel *kztab)
 	lock = kz_tab_label_get_lock(kztab);
 	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), lock);
 
+	action = gtk_action_group_get_action(kz->tabpop_actions,
+					     "TabAutoRefresh");
+	auto_refresh = kz_tab_label_get_auto_refresh(kztab);
+	gtk_toggle_action_set_active(GTK_TOGGLE_ACTION(action), auto_refresh);
+
 	action = gtk_action_group_get_action(kz->tabpop_actions,
 					     "TabClose");
 	g_object_set(action, "sensitive", !lock, NULL);
@@ -376,8 +400,7 @@ void
 kz_actions_tab_popup_menu_modal (KzTabLabel *kztab, guint button, guint time)
 {
 	GtkWidget *popup_menu = NULL;
-	gchar path[64];
-
+	
 	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
 	g_return_if_fail(KZ_IS_WINDOW(kztab->kz));
 
@@ -386,9 +409,8 @@ kz_actions_tab_popup_menu_modal (KzTabLabel *kztab, guint button, guint time)
 
 	g_object_set_qdata(G_OBJECT(kztab->kz), kztab_quark, kztab);
 
-	g_snprintf(path, sizeof(path), "/TabPopup%s",
-		   kz_ui_level_to_suffix(kz_ui_level()));
-	popup_menu = gtk_ui_manager_get_widget(kztab->kz->menu_merge, path);
+	popup_menu = gtk_ui_manager_get_widget(kztab->kz->menu_merge, 
+					       "/TabPopup");
 	if (!popup_menu) return;
 
 	set_popup_menu_sensitive(kztab);
