@@ -19,12 +19,13 @@
  */
 
 #include "kz-history-action.h"
+#include "kazehakase.h"
+#include "migemo.h"
 
 #include <string.h>
+#include <glib/gi18n.h>
 
 #include "gobject-utils.h"
-#include "intl.h"
-#include "gtk24backports.h"
 
 
 enum {
@@ -32,6 +33,14 @@ enum {
 	LAST_SIGNAL
 };
 
+enum {
+	COLUMN_TERMINATOR = -1,
+	COLUMN_FAVICON,
+	COLUMN_URI,
+	COLUMN_TIRLE,
+	N_COLUMN
+};
+
 
 static void       kz_history_action_class_init       (KzHistoryActionClass *klass);
 static void       kz_history_action_init             (KzHistoryAction *action);
@@ -41,7 +50,7 @@ static void       kz_history_action_activate         (GtkAction *action);
 static GtkWidget *kz_history_action_create_menu_item (GtkAction *action);
 static GtkWidget *kz_history_action_create_tool_item (GtkAction *action);
 
-static GtkCombo  *kz_history_action_real_get_combo_widget
+static GtkComboBox  *kz_history_action_real_get_combo_widget
 						     (KzHistoryAction *action,
 						      GtkWidget        *proxy);
 static void       kz_history_action_real_set_history (KzHistoryAction *action,
@@ -103,7 +112,13 @@ static void
 kz_history_action_init (KzHistoryAction *action)
 {
 	action->max_history = 32;
-	action->history     = NULL;
+	action->list_store = gtk_list_store_new(N_COLUMN,
+						GDK_TYPE_PIXBUF,
+						G_TYPE_STRING,
+						G_TYPE_STRING);
+	action->completion = NULL;
+	action->completion_egg_regex = NULL;
+	action->completion_previous_key = NULL;
 }
 
 
@@ -112,11 +127,28 @@ kz_history_action_dispose (GObject *object)
 {
 	KzHistoryAction *action = KZ_HISTORY_ACTION(object);
 
-	if (action->history)
+	if (action->list_store)
 	{
-		g_list_foreach (action->history, (GFunc) g_free, NULL);
-		g_list_free(action->history);
-		action->history = NULL;
+		g_object_unref(action->list_store);
+		action->list_store = NULL;
+	}
+
+	if (action->completion)
+	{
+		g_object_unref(action->completion);
+		action->completion = NULL;
+	}
+
+	if (action->completion_egg_regex)
+	{
+		egg_regex_free(action->completion_egg_regex);
+		action->completion_egg_regex = NULL;
+	}
+
+	if(action->completion_previous_key)
+	{
+		g_free(action->completion_previous_key);
+		action->completion_previous_key = NULL;
 	}
 
 	if (G_OBJECT_CLASS (parent_class)->dispose)
@@ -124,6 +156,52 @@ kz_history_action_dispose (GObject *object)
 }
 
 
+typedef struct _FindRow
+{
+	const gchar *uri;
+	GtkTreePath *path;
+} FindRow;
+
+
+static gboolean
+find_row_func (GtkTreeModel *model,
+	       GtkTreePath *path, GtkTreeIter *iter,
+	       gpointer data)
+{
+	FindRow *findrow = data;
+	gchar *uri;	
+
+	gtk_tree_model_get(model, iter,
+			   COLUMN_URI, &uri,
+			   COLUMN_TERMINATOR);
+
+	if (!strcmp(findrow->uri, uri))
+	{
+		findrow->path = gtk_tree_path_copy(path);
+		g_free(uri);
+		return TRUE;
+	}
+
+	g_free(uri);
+	return FALSE;
+}
+
+
+static GtkTreePath *
+find_row (GtkTreeModel *model, const gchar *uri)
+{
+	FindRow findrow;
+
+	g_return_val_if_fail(GTK_IS_TREE_MODEL(model), NULL);
+
+	findrow.uri = uri;
+	findrow.path = NULL;
+	gtk_tree_model_foreach(model, find_row_func, &findrow);
+
+	return findrow.path;
+}
+
+
 static void
 kz_history_action_activate (GtkAction *action)
 {
@@ -134,58 +212,43 @@ kz_history_action_activate (GtkAction *action)
 
 	if (text && *text)
 	{
-		GList *node;
-		GSList *snode, *proxies;
-		GList *prev;
+		GtkTreeIter iter;
+		GtkTreePath *path;
 
 		/* append, or reorder history */
-		prev = g_list_find_custom(hist_act->history, text,
-					  (GCompareFunc)strcmp);
-
-		if (prev)
-		{
-			text = prev->data;
-			hist_act->history = g_list_remove(hist_act->history,
-							  text);
+		path = find_row(GTK_TREE_MODEL(hist_act->list_store), text);
+		if (path)
+		{	
+			gtk_tree_model_get_iter(GTK_TREE_MODEL(hist_act->list_store),
+						&iter, path);
+			gtk_list_store_move_after(hist_act->list_store,
+						  &iter, NULL);
+			gtk_tree_path_free(path);
 		}
 		else
 		{
-			text = g_strdup(text);
-		}
-
-		hist_act->history = g_list_prepend(hist_act->history,
-						   (gpointer) text);
-
-		/* check max history */
-		if (g_list_length(hist_act->history) > hist_act->max_history)
-		{
-			node = g_list_nth(hist_act->history, hist_act->max_history);
-			while (node)
+			gint n_row;
+			gtk_list_store_prepend(hist_act->list_store,
+					       &iter);
+			gtk_list_store_set (hist_act->list_store, &iter,
+					    COLUMN_URI, text,
+					    COLUMN_TERMINATOR);
+			n_row = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(hist_act->list_store),
+							      NULL);
+			while (n_row > hist_act->max_history)
 			{
-				GList *tmp;
-				gchar *str = node->data;
-
-				tmp = g_list_next(node);
-				hist_act->history = g_list_remove(hist_act->history, str);
-				g_free(str);
-				node = tmp;
+				gboolean ret;
+				ret = gtk_tree_model_iter_nth_child(
+						GTK_TREE_MODEL(hist_act->list_store),
+						&iter, NULL, n_row);
+				if (ret)
+				{
+					gtk_list_store_remove(hist_act->list_store,
+							      &iter);
+				}
+				n_row--;
 			}
 		}
-
-		proxies = gtk_action_get_proxies(action);
-		/* set history to all proxy widgets */
-		for (snode = proxies; snode; snode = g_slist_next(snode))
-		{
-			GtkCombo *combo;
-			GtkWidget *proxy = snode->data;
-
-			combo = kz_history_action_get_combo_widget
-					(KZ_HISTORY_ACTION(action),
-					 proxy);
-			if (GTK_IS_COMBO(combo))
-				gtk_combo_set_popdown_strings(combo,
-							      hist_act->history);
-		}
 	}
 
 	g_signal_emit(G_OBJECT(action),
@@ -232,6 +295,119 @@ cb_menu_item_combo_leave (GtkWidget *widget, GdkEventCrossing *event)
 }
 
 
+static gboolean
+cb_match_selected (GtkEntryCompletion *completion,
+		   GtkTreeModel *model,
+		   GtkTreeIter *iter,
+		   GtkEntry *entry)
+{
+	char *item = NULL;
+
+	gtk_tree_model_get (model, iter, 
+			    COLUMN_URI, &item,
+			    COLUMN_TERMINATOR);
+
+	gtk_entry_set_text(entry, item);
+
+	g_signal_emit_by_name (entry, "activate");
+
+	g_free (item);
+
+	return TRUE;
+}
+
+static gboolean
+completion_func (GtkEntryCompletion *completion,
+		 const char *key,
+		 GtkTreeIter *iter,
+		 gpointer data)
+{
+	char *item = NULL;
+	gboolean ret = FALSE;
+	GtkTreeModel *model;
+	GError *e = NULL;
+	KzHistoryAction *action = KZ_HISTORY_ACTION(data);
+
+	model = gtk_entry_completion_get_model (completion);
+
+	gtk_tree_model_get (model, iter,
+			    COLUMN_URI, &item,
+			    COLUMN_TERMINATOR);
+
+	if (!item) return ret;
+
+	if (action->completion_previous_key && 
+	    strcmp(action->completion_previous_key, key))
+	{
+		egg_regex_free(action->completion_egg_regex);
+		action->completion_egg_regex = NULL;
+
+		g_free(action->completion_previous_key);
+		action->completion_previous_key = NULL;
+	}
+
+	if(!action->completion_egg_regex)
+	{
+#if USE_MIGEMO
+		gboolean use_migemo;
+#endif /* USE_MIGEMO */
+
+#if USE_MIGEMO
+		KZ_CONF_GET("Global", "use_migemo", use_migemo, BOOL);
+		if (use_migemo)
+		{
+			gchar* regex = migemo_get_regex(key);
+			if (regex)
+			{
+				action->completion_egg_regex = egg_regex_new(regex,
+								     EGG_REGEX_MULTILINE |
+								     EGG_REGEX_EXTENDED,
+								     0, &e);
+				if (e)
+				{
+					g_warning("%s", e->message);
+					g_error_free(e);
+					e = NULL;
+				}
+				g_free(regex);
+			}
+		}
+		else
+#endif /* USE_MIGEMO */
+		{
+			action->completion_egg_regex = egg_regex_new(key,
+							     EGG_REGEX_MULTILINE |
+							     EGG_REGEX_EXTENDED,
+							     0, &e);
+
+			if (e)
+			{
+				g_warning("%s", e->message);
+				g_error_free(e);
+				e = NULL;
+			}
+		}
+
+                /* reference */
+		if(action->completion_egg_regex)
+		{
+			action->completion_previous_key = g_strdup(key);
+		}
+		else
+		{
+			goto END;
+		}
+	}
+
+	if (egg_regex_match(action->completion_egg_regex, item, -1, 0) > 0)
+	{
+		ret = TRUE;
+	}
+ END:
+	g_free (item);
+	return ret;
+}
+
 static GtkWidget *
 kz_history_action_create_menu_item (GtkAction *action)
 {
@@ -239,7 +415,9 @@ kz_history_action_create_menu_item (GtkAction *action)
 
 #warning FIXME! implement as our original widget and force blink cursor.
 	widget = gtk_menu_item_new();
-	combo = gtk_combo_new();
+	combo = gtk_combo_box_entry_new_with_model(
+				GTK_TREE_MODEL(KZ_HISTORY_ACTION(action)->list_store),
+				COLUMN_URI);
 	gtk_widget_show(combo);
 	gtk_container_add(GTK_CONTAINER(widget), combo);
 
@@ -269,10 +447,11 @@ kz_history_action_create_tool_item (GtkAction *action)
 	widget = GTK_WIDGET(g_object_new(toolbar_item_type, NULL));
 	gtk_tool_item_set_expand (GTK_TOOL_ITEM(widget), TRUE);
 
-	combo = gtk_combo_new();
+	combo = gtk_combo_box_entry_new_with_model(
+				GTK_TREE_MODEL(KZ_HISTORY_ACTION(action)->list_store),
+				COLUMN_URI);
 	gtk_container_add(GTK_CONTAINER(widget), combo);
 	gtk_container_set_border_width(GTK_CONTAINER(widget), 4);
-	gtk_combo_disable_activate(GTK_COMBO(combo));
 	gtk_widget_show(combo);
 
 	return widget;
@@ -282,46 +461,36 @@ kz_history_action_create_tool_item (GtkAction *action)
 static void
 kz_history_action_connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
-	GtkCombo *combo;
+	GtkComboBox *combo;
 
 	g_return_if_fail(proxy);
 
 
-	if (KZ_HISTORY_ACTION(action)->history)
+	combo = kz_history_action_get_combo_widget(KZ_HISTORY_ACTION(action),
+						   proxy);
+	if (GTK_IS_COMBO_BOX(combo))
 	{
-		combo = kz_history_action_get_combo_widget(KZ_HISTORY_ACTION(action),
-							    proxy);
-		if (GTK_IS_COMBO(combo))
-		{
-			gtk_combo_set_popdown_strings
-				(GTK_COMBO(combo), KZ_HISTORY_ACTION(action)->history);
-			gtk_entry_set_text(GTK_ENTRY(combo->entry), "");
-		}
+		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(combo)->child), "");
 	}
 	GTK_ACTION_CLASS(parent_class)->connect_proxy(action, proxy);
 }
 
 
-static GtkCombo *
+static GtkComboBox *
 kz_history_action_real_get_combo_widget (KzHistoryAction *action, GtkWidget *proxy)
 {
-	GtkCombo *combo = NULL;
+	GtkComboBox *combo = NULL;
 
 	g_return_val_if_fail(proxy, NULL);
 
-	if (GTK_IS_BIN(proxy))
-		combo = GTK_COMBO(GTK_BIN(proxy)->child);
-	else
-		combo = GTK_COMBO(proxy);
-
-	if (GTK_IS_COMBO(combo))
+	if (GTK_IS_COMBO_BOX(combo))
 		return combo;
 
 	return NULL;
 }
 
 
-GtkCombo *
+GtkComboBox *
 kz_history_action_get_combo_widget (KzHistoryAction *action, GtkWidget *proxy)
 {
 	KzHistoryActionClass *klass;
@@ -340,45 +509,29 @@ kz_history_action_get_combo_widget (KzHistoryAction *action, GtkWidget *proxy)
 static void
 kz_history_action_real_set_history (KzHistoryAction *action, GList *list)
 {
-	GList *node, *new_list = NULL;
-	GSList *snode, *proxies;
+	GList *node;
 	gint num = 0;
 
 	g_return_if_fail(KZ_IS_ENTRY_ACTION(action));
 
+	/* remove old list store for combobox */
+	gtk_list_store_clear(action->list_store);
+	
 	/* dup the list */
 	for (node = list, num = 0;
 	     node && num < action->max_history;
 	     node = g_list_next(node), num++)
 	{
+		GtkTreeIter iter;
 		const gchar *text = node->data;
 
 		if (text && *text)
-			new_list = g_list_append(new_list, g_strdup(text));
-	}
-
-	/* free old list */
-	g_list_foreach(action->history, (GFunc) g_free, NULL);
-	g_list_free(action->history);
-
-	/* set history */
-	action->history = new_list;
-
-	proxies = gtk_action_get_proxies(GTK_ACTION(action));
-	/* set history to all proxy widgets */
-	for (snode = proxies;
-	     snode;
-	     snode = g_slist_next(snode))
-	{
-		GtkCombo *combo;
-		GtkWidget *proxy = snode->data;
-
-		combo = kz_history_action_get_combo_widget
-				(KZ_HISTORY_ACTION(action),
-				 proxy);
-		if (GTK_IS_COMBO(combo))
-			gtk_combo_set_popdown_strings(combo,
-						      action->history);
+		{
+			gtk_list_store_append (action->list_store, &iter);
+			gtk_list_store_set (action->list_store, &iter,
+					    COLUMN_URI, text,
+					    COLUMN_TERMINATOR);
+		}
 	}
 
 	g_signal_emit(G_OBJECT(action),
@@ -400,12 +553,33 @@ kz_history_action_set_history (KzHistoryAction *action, GList *list)
 }
 
 
-const GList *
+GList *
 kz_history_action_get_history (KzHistoryAction *action)
 {
+	GList *history = NULL;
+	gchar *uri;
+	GtkTreeIter iter;
+	GtkTreeModel *model;
+
 	g_return_val_if_fail(KZ_IS_ENTRY_ACTION(action), NULL);
 
-	return action->history;
+	model = GTK_TREE_MODEL(action->list_store);
+
+	if (!gtk_tree_model_get_iter_first(model, &iter))
+		return NULL;
+
+	while (1)
+	{
+		gtk_tree_model_get(model, &iter,
+				   COLUMN_URI, &uri,
+				   COLUMN_TERMINATOR);
+	
+		history = g_list_append (history, uri);
+	     	if (!gtk_tree_model_iter_next(model, &iter))
+			break;
+	}
+
+	return history;
 }
 
 
@@ -425,3 +599,46 @@ kz_history_action_get_max_history (KzHistoryAction *action)
 
 	return action->max_history;
 }
+
+void
+kz_history_set_completion (KzHistoryAction *action, 
+			   GtkEntry *entry)
+{
+	GtkCellRenderer *cell;
+	GtkTreeModel *model;
+
+	action->completion = gtk_entry_completion_new ();
+	model = GTK_TREE_MODEL(action->list_store);
+
+	gtk_entry_completion_set_model (action->completion, model);
+	gtk_entry_completion_set_match_func (action->completion, completion_func, action, NULL);
+	g_signal_connect (action->completion, "match_selected",
+			  G_CALLBACK (cb_match_selected), entry);
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (action->completion),
+				    cell, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (action->completion),
+				       cell, "text", COLUMN_URI);
+
+	gtk_entry_set_completion (entry, action->completion);
+}
+
+void
+kz_history_unset_completion (KzHistoryAction *action, 
+			     GtkEntry *entry)
+{
+	action->completion = gtk_entry_completion_new ();
+
+	gtk_entry_completion_set_model (action->completion, NULL);
+	g_signal_handlers_disconnect_by_func
+			(G_OBJECT(action->completion),
+			 G_CALLBACK(cb_match_selected),
+			 entry);
+
+	g_object_unref(action->completion);
+	action->completion = NULL;
+
+	gtk_entry_set_completion (entry, NULL);
+}
+
