@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-actions-bookmark.c,v 1.30 2004/11/24 11:08:09 ikezoe Exp $
+ *  $Id: kz-actions-bookmark.c,v 1.32 2004/12/12 10:31:02 ikezoe Exp $
  */
 
 #include "kz-actions-bookmark.h"
@@ -27,6 +27,7 @@
 #include "kz-bookmark-edit-win.h"
 #include "kz-smart-bookmark.h"
 #include "kz-bookmark-file.h"
+#include "utils.h"
 
 static GtkActionEntry kz_actions_bookmark[];
 static const gint     kz_actions_bookmark_len;
@@ -182,6 +183,113 @@ act_insert_smart_bookmark (GtkAction *action, KzBookmarkEditor *editor)
 	g_object_unref(G_OBJECT(smart));
 }
 
+typedef enum {
+	MOZILLA_BOOKMARK = 0,
+	NETSCAPE_BOOKMARK,
+	FIREFOX_BOOKMARK,
+	GALEON_BOOKMARK,
+	KONQUEROR_BOOKMARK,
+	W3M_BOOKMARK
+} OTHER_BROWSERS_BOOKMARK_TYPE;
+
+static struct {
+	const gchar* search_dir;
+	const gchar* search_name;
+	const gint search_depth;
+	const gchar* description;
+} other_browsers_bookmark_map[] = {
+	{".mozilla", "bookmarks.html", 4, N_("Mozilla Bookmarks")},
+	{".netscape", "bookmarks.html", 4, N_("Netscape Bookmarks")},
+	{".firefox", "bookmarks.html", 4, N_("Firefox Bookmarks")},
+	{".galeon", "bookmarks.xbel", 1, N_("Galeon Bookmarks")},
+	{".kde/share/apps/konqueror", "bookmarks.xml", 1, N_("Konqueror Bookmarks")},
+	{".w3m" ,"bookmark.html", 1, N_("w3m Bookmarks")}
+};
+
+static void
+insert_other_browsers_bookmark(KzBookmarkEditor *editor, OTHER_BROWSERS_BOOKMARK_TYPE type)
+{
+        /* mozilla families require recursive searching to get its bookmark */
+	gchar *dir = NULL;
+	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
+
+	dir = g_build_filename (g_get_home_dir (),
+				other_browsers_bookmark_map[type].search_dir,
+				NULL);
+	if(dir)
+	{
+		GSList *list, *node;
+
+		list = find_file  (dir,
+				   other_browsers_bookmark_map[type].search_name,
+				   other_browsers_bookmark_map[type].search_depth);
+		for (node = list; node; node = g_slist_next(node))
+		{
+			if (g_file_test (node->data, G_FILE_TEST_IS_REGULAR))
+			{
+				KzBookmark *bookmark =
+					KZ_BOOKMARK(kz_bookmark_file_new (node->data,
+									  other_browsers_bookmark_map[type].description,
+									  NULL));
+				insert_bookmark_item(editor, bookmark);
+				g_object_unref(G_OBJECT(bookmark));
+
+#warning FIXME! Is this really needed?
+				kz_bookmark_file_load_start(KZ_BOOKMARK_FILE(bookmark));
+			}
+		}
+		g_slist_free(list);
+		g_free (dir);
+	}
+
+}
+static void
+act_insert_mozilla_bookmark (GtkAction *action, KzBookmarkEditor *editor)
+{
+	g_return_if_fail(GTK_IS_ACTION(action));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
+	insert_other_browsers_bookmark(editor, MOZILLA_BOOKMARK);
+}
+
+static void
+act_insert_netscape_bookmark (GtkAction *action, KzBookmarkEditor *editor)
+{
+	g_return_if_fail(GTK_IS_ACTION(action));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
+	insert_other_browsers_bookmark(editor, NETSCAPE_BOOKMARK);
+}
+
+static void
+act_insert_firefox_bookmark (GtkAction *action, KzBookmarkEditor *editor)
+{
+	g_return_if_fail(GTK_IS_ACTION(action));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
+	insert_other_browsers_bookmark(editor, FIREFOX_BOOKMARK);
+}
+
+static void
+act_insert_galeon_bookmark (GtkAction *action, KzBookmarkEditor *editor)
+{
+	g_return_if_fail(GTK_IS_ACTION(action));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
+	insert_other_browsers_bookmark(editor, GALEON_BOOKMARK);
+}
+
+static void
+act_insert_konqueror_bookmark (GtkAction *action, KzBookmarkEditor *editor)
+{
+	g_return_if_fail(GTK_IS_ACTION(action));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
+	insert_other_browsers_bookmark(editor, KONQUEROR_BOOKMARK);
+}
+
+static void
+act_insert_w3m_bookmark (GtkAction *action, KzBookmarkEditor *editor)
+{
+	g_return_if_fail(GTK_IS_ACTION(action));
+	g_return_if_fail(KZ_IS_BOOKMARK_EDITOR(editor));
+	insert_other_browsers_bookmark(editor, W3M_BOOKMARK);
+}
 
 static void
 act_insert_separator (GtkAction *action, KzBookmarkEditor *editor)
@@ -318,7 +426,6 @@ static GtkActionEntry kz_actions_bookmark[] =
   {"StockViewMenu",     NULL, N_("_View"),       NULL, NULL, NULL},
   {"StockGoMenu",       NULL, N_("_Go"),         NULL, NULL, NULL},
   {"StockModeMenu",     NULL, N_("_Mode"),       NULL, NULL, NULL},
-
   {"NewWindow",            KZ_STOCK_NEW_WINDOW,      N_("_New Window"),             "<control>N", N_("Open a new window"), G_CALLBACK(act_new_window)},
   {"CloseWindow",          KZ_STOCK_CLOSE_WINDOW,    N_("_Close Window"),           "<control>W", N_("Close the current window"), G_CALLBACK(act_close_window)},
 
@@ -327,9 +434,14 @@ static GtkActionEntry kz_actions_bookmark[] =
   {"InsertFolder",         KZ_STOCK_FOLDER,          N_("Insert _folder"),          "<control>F", N_("Insert a new folder"), G_CALLBACK(act_insert_folder)},
   {"InsertRemoteBookmark", KZ_STOCK_REMOTE_BOOKMARK, N_("Insert _remote bookmark"), "<control>R", N_("Insert a new remote bookmark"), G_CALLBACK(act_insert_remote_bookmark)},
   {"InsertSmartBookmark", KZ_STOCK_SMART_BOOKMARK, N_("Insert _smart bookmark"), "<control>S", N_("Insert a new smart bookmark"), G_CALLBACK(act_insert_smart_bookmark)},
+  {"InsertMozillaBookmark", KZ_STOCK_MOZILLA, N_("Insert _Mozilla bookmark"), NULL, N_("Insert a Mozilla bookmark"), G_CALLBACK(act_insert_mozilla_bookmark)},
+  {"InsertNetscapeBookmark", KZ_STOCK_NETSCAPE, N_("Insert Netscape bookmark"), NULL, N_("Insert a Netscape bookmark"), G_CALLBACK(act_insert_netscape_bookmark)},
+  {"InsertFirefoxBookmark", KZ_STOCK_FIREFOX, N_("Insert Firefox bookmark"), NULL, N_("Insert a Firefox bookmark"), G_CALLBACK(act_insert_firefox_bookmark)},
+  {"InsertGaleonBookmark", KZ_STOCK_GALEON, N_("Insert Galeon bookmark"), NULL, N_("Insert a Galeon bookmark"), G_CALLBACK(act_insert_galeon_bookmark)},
+  {"InsertKonquerorBookmark", KZ_STOCK_KONQUEROR, N_("Insert Konqueror bookmark"), NULL, N_("Insert a Konqueror bookmark"), G_CALLBACK(act_insert_konqueror_bookmark)},
+  {"InsertW3mBookmark", NULL, N_("Insert w3m bookmark"), NULL, N_("Insert a w3m bookmark"), G_CALLBACK(act_insert_w3m_bookmark)},
   {"InsertSeparator",      KZ_STOCK_SEPARATOR,       N_("Insert _separator"),       "<control>P", N_("Insert a separator"), G_CALLBACK(act_insert_separator)},
   {"RemoveBookmarkItem",   GTK_STOCK_DELETE,         N_("_Remove selected item"),   "<control>Delete",     N_("Remove the selected item"), G_CALLBACK(act_remove_selected_item)},
-
   {"GoUp",  GTK_STOCK_GO_UP, N_("_Up"), NULL, NULL, G_CALLBACK(act_go_up)},
 };
 static const gint kz_actions_bookmark_len = G_N_ELEMENTS(kz_actions_bookmark);
