@@ -384,10 +384,10 @@ kz_bookmark_bar_drag_data_received (GtkWidget *widget,
 {
 	KzBookmarkBar *bar;
 	KzBookmark *bookmark, *sibling, *parent;
-	gchar **strings;
+	gchar **strings = NULL; 
 	GtkWidget *src_widget;
 	const gchar *title;
-	gchar *utf8_title;
+	gchar *utf8_title = NULL;
 	GList *children;
 	gint index;
 
@@ -434,13 +434,16 @@ kz_bookmark_bar_drag_data_received (GtkWidget *widget,
 	 case TARGET_TEXT_URI_LIST:
 		if (data->length < 0) return;
 		strings = g_strsplit(data->data, "\n", 2);
-		
-		utf8_title = g_locale_to_utf8(strings[1],
-					      strlen(strings[1]),
-					      NULL,
-					      NULL,
-					      NULL);
-		if (!utf8_title || g_utf8_validate(utf8_title, -1, NULL))
+		if (!strings) return;
+		if (strings[1] != NULL)
+		{
+			utf8_title = g_locale_to_utf8(strings[1],
+						      strlen(strings[1]),
+						      NULL,
+						      NULL,
+						      NULL);
+		}
+		if (utf8_title && g_utf8_validate(utf8_title, -1, NULL))
 			title = utf8_title;
 		else 
 			title = _("title");
