@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-editor.c,v 1.37 2004/09/30 00:06:06 ikezoe Exp $
+ *  $Id: kz-bookmark-editor.c,v 1.38 2004/10/30 00:32:48 ikezoe Exp $
  */
 
 #include "kz-bookmark-editor.h"
@@ -32,6 +32,7 @@
 #include "kz-actions-bookmark.h"
 #include "kz-icons.h"
 #include "kz-bookmarks-view.h"
+#include "kz-bookmark-file.h"
 
 
 enum {
@@ -385,10 +386,10 @@ kz_bookmark_editor_set_bookmark_tree (KzBookmarkEditor *editor,
 		SET_SENSITIVE(editor, "GoUp", TRUE);
 	}
 
-	if (parent && !kz_bookmark_is_file(parent))
+	if (parent && !KZ_IS_BOOKMARK_FILE(parent))
 		parent = kz_bookmark_get_parent_file(parent);
 
-	if (parent && kz_bookmark_file_is_editable(parent))
+	if (parent && kz_bookmark_file_is_editable(KZ_BOOKMARK_FILE(parent)))
 		editable = TRUE;
 	else
 		editable = FALSE;
