@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark.c,v 1.73 2004/11/22 01:08:41 ikezoe Exp $
+ *  $Id: kz-bookmark.c,v 1.74 2004/12/05 08:06:06 tyuyu Exp $
  */
 
 #include "kz-bookmark.h"
@@ -54,7 +54,8 @@ enum {
 	PROP_ADDED_TIME,
 	PROP_INTERVAL,
 	PROP_CURRENT_POS,
-	PROP_LOCK
+	PROP_LOCK,
+	PROP_AUTO_REFRESH
 };
 
 
@@ -91,6 +92,7 @@ static GQuark parent_quark            = 0;
 static GQuark children_quark          = 0;
 static GQuark current_pos_quark       = 0;
 static GQuark lock_quark              = 0;
+static GQuark auto_refresh_quark      = 0;
 
 GType
 kz_bookmark_type_get_type (void)
@@ -244,11 +246,21 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 
 	g_object_class_install_property(
 		object_class,
-		 PROP_LOCK,
-		 g_param_spec_boolean(
-			 "lock",
-			 _("Lock state"),
-			 _("Lock state for tab"),
+		PROP_LOCK,
+		g_param_spec_boolean(
+			"lock",
+			_("Lock state"),
+			_("Lock state for tab"),
+			FALSE,
+			 G_PARAM_READWRITE));
+
+	g_object_class_install_property(
+		object_class,
+		PROP_AUTO_REFRESH,
+		g_param_spec_boolean(
+			 "auto-refresh",
+			 _("Auto Refresh state"),
+			 _("Auto Refresh state for tab"),
 			 FALSE,
 			 G_PARAM_READWRITE));
 
@@ -302,21 +314,21 @@ kz_bookmark_class_init (KzBookmarkClass *klass)
 	 *   * ......
 	 */
 
-	id_quark          = g_quark_from_string("KzBookmark::ID");
-	title_quark       = g_quark_from_string("KzBookmark::Title");
-	doc_title_quark   = g_quark_from_string("KzBookmark::DocumentTitle");
-	link_quark        = g_quark_from_string("KzBookmark::Link");
-	description_quark = g_quark_from_string("KzBookmark::Description");
-	last_mod_quark    = g_quark_from_string("KzBookmark::LastModified");
-	last_visited_quark= g_quark_from_string("KzBookmark::LastVisited");
-	added_time_quark  = g_quark_from_string("KzBookmark::AddedTime");
-	parent_quark      = g_quark_from_string("KzBookmark::Parent");
-	children_quark    = g_quark_from_string("KzBookmark::Children");
-	current_pos_quark = g_quark_from_string("KzBookmark::Current");
-	lock_quark        = g_quark_from_string("KzBookmark::Lock");
+	id_quark           = g_quark_from_string("KzBookmark::ID");
+	title_quark        = g_quark_from_string("KzBookmark::Title");
+	doc_title_quark    = g_quark_from_string("KzBookmark::DocumentTitle");
+	link_quark         = g_quark_from_string("KzBookmark::Link");
+	description_quark  = g_quark_from_string("KzBookmark::Description");
+	last_mod_quark     = g_quark_from_string("KzBookmark::LastModified");
+	last_visited_quark = g_quark_from_string("KzBookmark::LastVisited");
+	added_time_quark   = g_quark_from_string("KzBookmark::AddedTime");
+	parent_quark       = g_quark_from_string("KzBookmark::Parent");
+	children_quark     = g_quark_from_string("KzBookmark::Children");
+	current_pos_quark  = g_quark_from_string("KzBookmark::Current");
+	lock_quark         = g_quark_from_string("KzBookmark::Lock");
+	auto_refresh_quark = g_quark_from_string("KzBookmark::AutoRefresh");
 }
 
-
 static void
 kz_bookmark_init (KzBookmark *bookmark)
 {
@@ -404,6 +416,11 @@ kz_bookmark_set_property (GObject *object,
 		g_object_set_qdata(object, lock_quark,
 				   GINT_TO_POINTER(g_value_get_boolean(value)));
 		break;
+	case PROP_AUTO_REFRESH:
+		g_return_if_fail(kz_bookmark_is_folder(bookmark));
+		g_object_set_qdata(object, auto_refresh_quark,
+				   GINT_TO_POINTER(g_value_get_boolean(value)));
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -470,6 +487,11 @@ kz_bookmark_get_property (GObject *object,
 							  lock_quark));
 		g_value_set_boolean(value, time);
 		break;
+	case PROP_AUTO_REFRESH:
+		time = GPOINTER_TO_INT(g_object_get_qdata(object,
+							  auto_refresh_quark));
+		g_value_set_boolean(value, time);
+		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
 		break;
@@ -987,6 +1009,23 @@ kz_bookmark_set_lock (KzBookmark  *bookmark,
 	g_object_set(G_OBJECT(bookmark), "lock", lock, NULL);
 }
 
+gboolean
+kz_bookmark_get_auto_refresh (KzBookmark  *bookmark)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return FALSE;
+
+	return GPOINTER_TO_INT(g_object_get_qdata(G_OBJECT(bookmark),
+						  auto_refresh_quark));
+}
+
+void
+kz_bookmark_set_auto_refresh (KzBookmark  *bookmark,
+			      gboolean auto_refresh)
+{
+	if (!kz_bookmark_is_folder(bookmark)) return;
+
+	g_object_set(G_OBJECT(bookmark), "auto-refresh", auto_refresh, NULL);
+}
 
 static gint 
 compare_func (gconstpointer a, gconstpointer b)
