@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-history.c,v 1.30 2004/10/17 07:25:18 makeinu Exp $
+ *  $Id: kz-history.c,v 1.31 2004/10/30 00:32:49 ikezoe Exp $
  */
 
 #include "kz-history.h"
@@ -30,12 +30,12 @@ static void kz_history_class_init (KzHistoryClass *klass);
 static void kz_history_init       (KzHistory      *history);
 static void kz_history_dispose    (GObject        *object);
 
-static KzBookmarkClass *parent_class = NULL;
+static KzBookmarkFileClass *parent_class = NULL;
 
 
 KZ_OBJECT_GET_TYPE(kz_history, "KzHistory", KzHistory,
 		   kz_history_class_init, kz_history_init,
-		   KZ_TYPE_BOOKMARK)
+		   KZ_TYPE_BOOKMARK_FILE)
 
 
 static void
@@ -87,7 +87,6 @@ kz_history_new (const gchar *file)
 			   "file-type", "XBEL", 
 			   NULL);
 	bookmark = KZ_BOOKMARK(obj);
-	bookmark->flags |= KZ_BOOKMARK_FILE_FLAG;
 
 	return KZ_HISTORY(bookmark);
 }
