@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xbel.c,v 1.59 2004/12/05 08:06:06 tyuyu Exp $
+ *  $Id: kz-xbel.c,v 1.60 2005/02/05 11:02:51 ikezoe Exp $
  */
 
 #include "kazehakase.h"
@@ -166,13 +166,13 @@ kz_xbel_from_string (KzBookmarkFile *bookmark,
 		const gchar *bookmark_title;
 
 		/*
-		 *  <xbel version=1.0 folded=none>\n (space1)
+		 *  <xbel version=1.0 folded=no>\n (space1)
 		 *  <title>Bookmarks</title>\n       (space2)
 		 *  </xbel>
 		 */
 		node = kz_xml_element_node_new("xbel");
 		kz_xml_node_set_attr(node, "version", "1.0");
-		kz_xml_node_set_attr(node, "folded", "none");	
+		kz_xml_node_set_attr(node, "folded", "no");	
 		kz_xml_node_set_attr(node, "xmlns:kz", KAZEHAKASE_URI"2004");	
 		/* kz_xml_node_set_attr(node, "id", "????????"); */
 		kz_xml_node_append_child(xml->root, node);
