@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-sidebar.c,v 1.15 2004/10/02 00:48:01 ikezoe Exp $
+ *  $Id: kz-sidebar.c,v 1.16 2004/11/22 01:08:41 ikezoe Exp $
  */
 
 #include "kz-sidebar.h"
@@ -221,9 +221,9 @@ kz_sidebar_new (KzWindow *kz)
 {
 	KzSidebar *sidebar;
 
-	sidebar = KZ_SIDEBAR(g_object_new(KZ_TYPE_SIDEBAR,
-					  "kz-window", kz,
-					  NULL));
+	sidebar = g_object_new(KZ_TYPE_SIDEBAR,
+			       "kz-window", kz,
+			       NULL);
 
 	kz_sidebar_set_current(sidebar, sidebar_entries[0]->label);
 
