@@ -46,11 +46,15 @@ struct _KzTabLabelPriv
 	gint start_x, start_y;
 	gboolean moved;
 	gboolean lock;
+	gboolean auto_refresh;
+	guint auto_refresh_id;
 	gulong favicon_signal;
 };
 
 static gchar *label_color[KZ_TAB_LABEL_N_STATE];
 
+#define DEFAULT_AUTO_REFRESH_INTERVAL_SEC 300
+
 /* object class */
 static void     kz_tab_label_class_init         (KzTabLabelClass *klass);
 static void     kz_tab_label_init               (KzTabLabel *kztab);
@@ -230,6 +234,8 @@ kz_tab_label_init (KzTabLabel *kztab)
 	kztab->priv->start_y           = 0;
 	kztab->priv->moved             = FALSE;
 	kztab->priv->lock              = FALSE;
+	kztab->priv->auto_refresh      = FALSE;
+	kztab->priv->auto_refresh_id   = 0;
 	kztab->priv->favicon_signal    = 0;
 	
 	kztab->favicon_pixbuf   = NULL;
@@ -637,7 +643,17 @@ kz_tab_label_button_press (GtkWidget *widget, GdkEventButton *event)
 						event->time);
 	}
 #endif
-
+	if (event->button == 2)
+	{
+		kz_window_close_tab(kztab->kz, GTK_WIDGET(kztab->kzembed));
+	}
+	if (event->type == GDK_2BUTTON_PRESS)
+	{
+		kz_embed_reload(kztab->kzembed,
+				(event->state & GDK_SHIFT_MASK) ?
+				KZ_EMBED_RELOAD_BYPASS_PROXY_AND_CACHE : 
+				KZ_EMBED_RELOAD_NORMAL);
+	}
 	if (GTK_WIDGET_CLASS(parent_class)->button_press_event)
 		GTK_WIDGET_CLASS(parent_class)->button_press_event(widget, event);
 	return FALSE;
@@ -1268,6 +1284,70 @@ kz_tab_label_set_lock (KzTabLabel *kztab, gboolean lock)
 	kz_tab_label_sync_to_profile(kztab);
 }
 
+static gboolean
+cb_auto_refresh(KzTabLabel* kztab)
+{
+	gint auto_refresh_interval_sec = DEFAULT_AUTO_REFRESH_INTERVAL_SEC;
+
+	g_return_val_if_fail(KZ_IS_TAB_LABEL(kztab), TRUE);
+
+	KZ_CONF_GET("Tab", "auto_refresh_interval_sec", auto_refresh_interval_sec, INT);
+
+	kz_embed_reload(KZ_EMBED(kztab->kzembed),
+			KZ_EMBED_RELOAD_NORMAL);
+
+	if (kztab->priv->auto_refresh_id != 0)
+		g_source_remove(kztab->priv->auto_refresh_id);
+
+	kztab->priv->auto_refresh_id
+		= g_timeout_add(auto_refresh_interval_sec * 1000,
+				(GSourceFunc)cb_auto_refresh, kztab);
+	return FALSE;
+}
+
+gboolean
+kz_tab_label_get_auto_refresh (KzTabLabel *kztab)
+{
+	g_return_val_if_fail(KZ_IS_TAB_LABEL(kztab), FALSE);
+	return kztab->priv->auto_refresh;
+
+}
+void
+kz_tab_label_set_auto_refresh (KzTabLabel *kztab, gboolean auto_refresh)
+{
+	gboolean save = FALSE;
+
+	g_return_if_fail(KZ_IS_TAB_LABEL(kztab));
+	if(auto_refresh)
+	{
+		gint auto_refresh_interval_sec = DEFAULT_AUTO_REFRESH_INTERVAL_SEC;
+		KZ_CONF_GET("Tab", "auto_refresh_interval_sec", auto_refresh_interval_sec, INT);
+
+		if (kztab->priv->auto_refresh_id != 0)
+			g_source_remove(kztab->priv->auto_refresh_id);
+
+		kztab->priv->auto_refresh_id 
+			= g_timeout_add(auto_refresh_interval_sec * 1000,
+					(GSourceFunc)cb_auto_refresh, kztab);
+	}
+	else
+	{
+		if (kztab->priv->auto_refresh_id != 0)
+		{
+			g_source_remove(kztab->priv->auto_refresh_id);
+			kztab->priv->auto_refresh_id = 0;
+		}
+	}
+	kztab->priv->auto_refresh = auto_refresh;
+	kz_actions_set_sensitive(kztab->kz, kztab->kzembed);
+
+	kz_bookmark_set_auto_refresh(kztab->history, auto_refresh);
+	KZ_CONF_GET("Session", "save", save, BOOL);
+	if (save)
+		kz_bookmark_file_save(KZ_BOOKMARK_FILE(kz_bookmarks->current_session));
+	kz_tab_label_sync_to_profile(kztab);
+}
+
 void
 kz_tab_label_set_history (KzTabLabel *kztab, KzBookmark *history)
 {	
