@@ -78,15 +78,9 @@ KzMozEventListener::HandleLink (nsIDOMNode *node)
 	nsCOMPtr<nsIDocument> doc = do_QueryInterface (domDoc);
 	if(!doc) return NS_ERROR_FAILURE;
 
-#if MOZILLA_SNAPSHOT > 12
 	nsIURI *nsURI;
 	nsURI = doc->GetDocumentURI ();
 	if (nsURI == NULL) return NS_ERROR_FAILURE;
-#else
-	nsIURI *nsURI;
-	nsURI = doc->GetDocumentURL ();
-	if (nsURI == NULL) return NS_ERROR_FAILURE;
-#endif
 
 	const nsACString &linkstring = NS_ConvertUCS2toUTF8(link);
 	nsCAutoString url;
