@@ -111,7 +111,7 @@ prefs_privacy_create (void)
 {
 	KzPrefsPrivacy *prefsui = g_new0(KzPrefsPrivacy, 1);
 	GtkWidget *main_vbox, *vbox, *hbox, *frame;
-	GtkWidget *radio1, *radio2, *radio3, *radio4;;
+	GtkWidget *radio1, *radio2, *radio3, *radio4;
 	GtkWidget *label, *spin, *check;
 	GtkWidget *button;
 	GtkAdjustment *adj;
@@ -209,14 +209,27 @@ prefs_privacy_create (void)
 
 	radio2 = gtk_radio_button_new_with_mnemonic_from_widget(
 		 	GTK_RADIO_BUTTON(radio1),
-			_("Accept for current _session only"));
-	gtk_box_pack_start(GTK_BOX(vbox), radio2, TRUE, TRUE, 2);
+			_("Ask for _each cookie"));
+	hbox = gtk_hbox_new(FALSE, 0);	
+	gtk_box_pack_start(GTK_BOX(hbox), radio2, FALSE, FALSE, 0);
+	prefsui->except_check = check =
+		gtk_check_button_new_with_mnemonic(_("e_xcept for session cookies"));
+	mozilla_prefs_get_boolean("network.cookie.alwaysAcceptSessionCookies", &except);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), except);
+	gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 2);
+	gtk_widget_set_sensitive(check, FALSE);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 2);
 
 	radio3 = gtk_radio_button_new_with_mnemonic_from_widget(
+		 	GTK_RADIO_BUTTON(radio1),
+			_("Accept for current _session only"));
+	gtk_box_pack_start(GTK_BOX(vbox), radio3, TRUE, TRUE, 2);
+
+	radio4 = gtk_radio_button_new_with_mnemonic_from_widget(
 		 	GTK_RADIO_BUTTON(radio1),
 			_("Accept cookie _for"));
 	hbox = gtk_hbox_new(FALSE, 0);	
-	gtk_box_pack_start(GTK_BOX(hbox), radio3, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(hbox), radio4, FALSE, FALSE, 0);
 	prefsui->span_spin = spin
 		= gtk_spin_button_new_with_range(0, 1000, 1);
 	adj = gtk_spin_button_get_adjustment(GTK_SPIN_BUTTON(spin));
@@ -231,18 +244,14 @@ prefs_privacy_create (void)
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 2);	
 	gtk_box_pack_start(GTK_BOX(vbox), hbox,   TRUE, TRUE, 2);
 
-	radio4 = gtk_radio_button_new_with_mnemonic_from_widget(
-		 	GTK_RADIO_BUTTON(radio1),
-			_("Ask for _each cookie"));
-	hbox = gtk_hbox_new(FALSE, 0);	
-	gtk_box_pack_start(GTK_BOX(hbox), radio4, FALSE, FALSE, 0);
-	prefsui->except_check = check =
-		gtk_check_button_new_with_mnemonic(_("e_xcept for session cookies"));
-	mozilla_prefs_get_boolean("network.cookie.alwaysAcceptSessionCookies", &except);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check), except);
-	gtk_box_pack_start(GTK_BOX(hbox), check, FALSE, FALSE, 2);
-	gtk_widget_set_sensitive(check, FALSE);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 2);
+	g_signal_connect(G_OBJECT(radio1), "toggled",
+			 G_CALLBACK(cb_changed), prefsui);
+	g_signal_connect(G_OBJECT(radio2), "toggled",
+			 G_CALLBACK(cb_lifespan_except_changed), prefsui);
+	g_signal_connect(G_OBJECT(radio3), "toggled",
+			 G_CALLBACK(cb_changed), prefsui);
+	g_signal_connect(G_OBJECT(radio4), "toggled",
+			 G_CALLBACK(cb_lifespan_span_changed), prefsui);
 	
 	mozilla_prefs_get_int("network.cookie.lifetimePolicy", &lifetime);
 	switch (lifetime)
@@ -264,14 +273,6 @@ prefs_privacy_create (void)
 		break;
 	}
 	
-	g_signal_connect(G_OBJECT(radio1), "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
-	g_signal_connect(G_OBJECT(radio2), "toggled",
-			 G_CALLBACK(cb_changed), prefsui);
-	g_signal_connect(G_OBJECT(radio3), "toggled",
-			 G_CALLBACK(cb_lifespan_span_changed), prefsui);
-	g_signal_connect(G_OBJECT(radio4), "toggled",
-			 G_CALLBACK(cb_lifespan_except_changed), prefsui);
 	gtk_widget_show_all(vbox);
 
 	/*
