@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmarks-sidebar.c,v 1.5 2004/09/30 00:06:07 ikezoe Exp $
+ *  $Id: kz-bookmarks-sidebar.c,v 1.6 2004/11/22 01:08:41 ikezoe Exp $
  */
 
 #include "kz-bookmarks-sidebar.h"
@@ -189,9 +189,9 @@ kz_bookmarks_sidebar_new (KzSidebar *sidebar)
 {
 	KzBookmarksSidebar *bsidebar;
 
-	bsidebar = KZ_BOOKMARKS_SIDEBAR(g_object_new(KZ_TYPE_BOOKMARKS_SIDEBAR,
-						     "sidebar", sidebar,
-						     NULL));
+	bsidebar = g_object_new(KZ_TYPE_BOOKMARKS_SIDEBAR,
+			        "sidebar", sidebar,
+			        NULL);
 
 	return GTK_WIDGET(bsidebar);
 }
