@@ -20,13 +20,12 @@
 
 #include "kz-tabtree.h"
 
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
 #include "kz-tab-label.h"
 #include "kz-actions-tab.h"
 
-
 #define NORMAL_COLOR  NULL
 #define LOADING_COLOR "red"
 
@@ -74,8 +73,9 @@ static void         build_tab_tree         (KzTabTree    *tabtree,
 					    GNode        *parent);
 static void         build_tab_list         (KzTabTree    *tabtree);
 static GtkTreeIter *find_node              (GtkTreeStore *store,
-					    KzMozEmbed   *kzembed);
-static void         remove_all_moz_signals (KzTabTree    *tabtree);
+					    KzEmbed      *kzembed);
+static void         remove_all_embed_signals
+					   (KzTabTree    *tabtree);
 
 /* signal handlers for TreeView */
 static void     cb_cursor_changed           (GtkTreeView     *tree_view,
@@ -106,12 +106,12 @@ static void     cb_reorder_tab    (KzWindow        *kz,
 				   gint             pos,
 				   KzTabTree       *tabtree);
 
-/* signal handlers for mozilla */
-static void     cb_net_start      (GtkMozEmbed     *embed,
+/* signal handlers for embed */
+static void     cb_net_start      (KzEmbed         *embed,
 				   KzTabTree       *tabtree);
-static void     cb_net_stop       (GtkMozEmbed     *embed,
+static void     cb_net_stop       (KzEmbed         *embed,
 				   KzTabTree       *tabtree);
-static void     cb_title_changed  (GtkMozEmbed     *embed,
+static void     cb_title_changed  (KzEmbed         *embed,
 				   KzTabTree       *tabtree);
 
 
@@ -365,7 +365,7 @@ kz_tab_tree_dispose (GObject *obj)
 
 	if (tabtree->store)
 	{
-		remove_all_moz_signals(tabtree);
+		remove_all_embed_signals(tabtree);
 		g_object_unref(tabtree->store);
 		tabtree->store = NULL;
 	}
@@ -425,10 +425,10 @@ kz_tab_list_new (KzSidebar *sidebar)
 {
 	KzTabTree *tabtree;
 
-	tabtree = KZ_TAB_TREE(g_object_new(KZ_TYPE_TAB_TREE,
-					   "sidebar", sidebar,
-					   "tree",    FALSE,
-					   NULL));
+	tabtree = g_object_new(KZ_TYPE_TAB_TREE,
+			       "sidebar", sidebar,
+			       "tree",    FALSE,
+			       NULL);
 
 	return GTK_WIDGET(tabtree);
 }
@@ -439,10 +439,10 @@ kz_tab_tree_new (KzSidebar *sidebar)
 {
 	KzTabTree *tabtree;
 
-	tabtree = KZ_TAB_TREE(g_object_new(KZ_TYPE_TAB_TREE,
-					   "sidebar", sidebar,
-					   "tree",    TRUE,
-					   NULL));
+	tabtree = g_object_new(KZ_TYPE_TAB_TREE,
+			       "sidebar", sidebar,
+			       "tree",    TRUE,
+			       NULL);
 
 	return GTK_WIDGET(tabtree);
 }
@@ -469,18 +469,18 @@ build_tab_tree (KzTabTree *tabtree, GNode *parent)
 	node = g_node_first_child(parent);
 	for (; node; node = g_node_next_sibling(node))
 	{
-		KzMozEmbed *kzembed = node->data;
+		KzEmbed *kzembed = node->data;
 		GNode *child = g_node_first_child(node);
 
-		if (KZ_IS_MOZ_EMBED(kzembed))
+		if (KZ_IS_EMBED(kzembed))
 		{
-			gchar *title = kz_moz_embed_ensure_title(kzembed);
-			const gchar *uri   = kz_moz_embed_get_location(kzembed);
+			gchar *title = kz_embed_ensure_title(kzembed);
+			const gchar *uri   = kz_embed_get_location(kzembed);
 			GdkPixbuf *favicon = kz_favicon_get_pixbuf(tabtree->sidebar->kz->kzfav,
 								   uri,
 								   GTK_ICON_SIZE_MENU);
 			const gchar *color;
-			color = kz_moz_embed_is_loading(kzembed)
+			color = kz_embed_is_loading(kzembed)
 				? LOADING_COLOR : NORMAL_COLOR;
 
 			gtk_tree_store_append(tabtree->store,
@@ -491,13 +491,13 @@ build_tab_tree (KzTabTree *tabtree, GNode *parent)
 					   COLUMN_TITLE_COLOR, color,
 					   COLUMN_EMBEDER,     kzembed,
 					   COLUMN_TERMINATOR);
-			g_signal_connect(G_OBJECT(kzembed), "title",
+			g_signal_connect(G_OBJECT(kzembed), "kz-title",
 					 G_CALLBACK(cb_title_changed),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "net-start",
+			g_signal_connect(G_OBJECT(kzembed), "kz-net-start",
 					 G_CALLBACK(cb_net_start),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "net-stop",
+			g_signal_connect(G_OBJECT(kzembed), "kz-net-stop",
 					 G_CALLBACK(cb_net_stop),
 					 tabtree);
 
@@ -533,21 +533,21 @@ build_tab_list (KzTabTree *tabtree)
 	kz = tabtree->sidebar->kz;
 	if (!kz) return;
 
-	num = gtkutil_notebook_get_n_pages(GTK_NOTEBOOK(kz->notebook));
+	num = gtk_notebook_get_n_pages(GTK_NOTEBOOK(kz->notebook));
 
 	for (i = 0; i < num; i++)
 	{
-		KzMozEmbed *kzembed = KZ_MOZ_EMBED(KZ_WINDOW_NTH_PAGE(kz, i));
+		KzEmbed *kzembed = KZ_EMBED(KZ_WINDOW_NTH_PAGE(kz, i));
 
-		if (KZ_IS_MOZ_EMBED(kzembed))
+		if (KZ_IS_EMBED(kzembed))
 		{
-			gchar *title = kz_moz_embed_ensure_title(kzembed);
+			gchar *title = kz_embed_ensure_title(kzembed);
 			const gchar *color;
-			const gchar *uri   = kz_moz_embed_get_location(kzembed);
+			const gchar *uri   = kz_embed_get_location(kzembed);
 			GdkPixbuf *favicon = kz_favicon_get_pixbuf(tabtree->sidebar->kz->kzfav,
 								   uri,
 								   GTK_ICON_SIZE_MENU);
-			color = kz_moz_embed_is_loading(kzembed)
+			color = kz_embed_is_loading(kzembed)
 				? LOADING_COLOR : NORMAL_COLOR;
 
 			gtk_tree_store_append(tabtree->store, &iter, NULL);
@@ -557,13 +557,13 @@ build_tab_list (KzTabTree *tabtree)
 					   COLUMN_TITLE_COLOR, color,
 					   COLUMN_EMBEDER,     kzembed,
 					   COLUMN_TERMINATOR);
-			g_signal_connect(G_OBJECT(kzembed), "title",
+			g_signal_connect(G_OBJECT(kzembed), "kz-title",
 					 G_CALLBACK(cb_title_changed),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "net-start",
+			g_signal_connect(G_OBJECT(kzembed), "kz-net-start",
 					 G_CALLBACK(cb_net_start),
 					 tabtree);
-			g_signal_connect(G_OBJECT(kzembed), "net-stop",
+			g_signal_connect(G_OBJECT(kzembed), "kz-net-stop",
 					 G_CALLBACK(cb_net_stop),
 					 tabtree);
 
@@ -581,7 +581,7 @@ build_tab_list (KzTabTree *tabtree)
 
 typedef struct _FindNode
 {
-	KzMozEmbed  *kzembed;
+	KzEmbed  *kzembed;
 	GtkTreeIter *iter;
 } FindNode;
 
@@ -591,7 +591,7 @@ find_node_func (GtkTreeModel *model,
 		GtkTreePath *path, GtkTreeIter *iter,
 		FindNode *data)
 {
-	KzMozEmbed *kzembed = NULL;
+	KzEmbed *kzembed = NULL;
 
 	if (!iter) return FALSE;
 
@@ -609,7 +609,7 @@ find_node_func (GtkTreeModel *model,
 
 
 static GtkTreeIter *
-find_node (GtkTreeStore *store, KzMozEmbed *kzembed)
+find_node (GtkTreeStore *store, KzEmbed *kzembed)
 {
 	FindNode data;
 	data.iter = NULL;
@@ -622,11 +622,11 @@ find_node (GtkTreeStore *store, KzMozEmbed *kzembed)
 
 
 static gboolean
-remove_moz_signal_func (GtkTreeModel *model,
-			GtkTreePath *path, GtkTreeIter *iter,
-			gpointer data)
+remove_embed_signal_func (GtkTreeModel *model,
+			  GtkTreePath *path, GtkTreeIter *iter,
+			  gpointer data)
 {
-	KzMozEmbed *kzembed = NULL;
+	KzEmbed *kzembed = NULL;
 	KzTabTree *tabtree;
 
 	g_return_val_if_fail(KZ_IS_TAB_TREE(data), FALSE);
@@ -654,13 +654,13 @@ remove_moz_signal_func (GtkTreeModel *model,
 
 
 static void
-remove_all_moz_signals (KzTabTree *tabtree)
+remove_all_embed_signals (KzTabTree *tabtree)
 {
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 	g_return_if_fail(GTK_IS_TREE_MODEL(tabtree->store));
 
 	gtk_tree_model_foreach(GTK_TREE_MODEL(tabtree->store),
-			       remove_moz_signal_func,
+			       remove_embed_signal_func,
 			       tabtree);
 }
 
@@ -677,7 +677,7 @@ cb_cursor_changed(GtkTreeView *tree_view, KzTabTree *tabtree)
 	GtkTreePath *treepath;
 	GtkTreeIter iter;
 	KzWindow *kz;
-	KzMozEmbed *kzembed = NULL;
+	KzEmbed *kzembed = NULL;
 	gint num;
 
 	g_return_if_fail(GTK_IS_TREE_VIEW(tree_view));
@@ -715,7 +715,7 @@ cb_tree_view_button_release (GtkWidget *widget, GdkEventButton *event,
 	GtkTreePath *treepath;
 	GtkTreeIter iter;
 	KzWindow *kz;
-	KzMozEmbed *kzembed = NULL;
+	KzEmbed *kzembed = NULL;
 	GtkWidget *label;
 
 	g_return_val_if_fail(GTK_IS_TREE_VIEW(widget), FALSE);
@@ -793,7 +793,7 @@ cb_switch_page (GtkNotebook *notebook, GtkNotebookPage *page,
 	if (tabtree->switching) return;
 
 	widget = gtk_notebook_get_nth_page(notebook, page_num);
-	iter = find_node(tabtree->store, KZ_MOZ_EMBED(widget));
+	iter = find_node(tabtree->store, KZ_EMBED(widget));
 	/* g_return_if_fail(iter); */
 	if (!iter) return;
 
@@ -823,7 +823,7 @@ cb_append_tab (KzWindow *kz, GtkWidget *widget, GtkWidget *parent,
 	tree = kz_window_get_tree(tabtree->sidebar->kz);
 
 	/* FIXME!! It's a quick hack */
-	remove_all_moz_signals(tabtree);
+	remove_all_embed_signals(tabtree);
 	gtk_tree_store_clear(tabtree->store);
 
 	if (tabtree->tree)
@@ -852,7 +852,7 @@ cb_remove_tab (KzWindow *kz, GtkWidget *widget,
 	tree = kz_window_get_tree(tabtree->sidebar->kz);
 
 	/* FIXME!! It's a quick hack */
-	remove_all_moz_signals(tabtree);
+	remove_all_embed_signals(tabtree);
 	gtk_tree_store_clear(tabtree->store);
 
 	if (tabtree->tree)
@@ -888,21 +888,21 @@ cb_reorder_tab (KzWindow *kz,
 
 /*****************************************************************************
  *                                                                           *
- *                         Callbacks for Mozilla                             *
+ *                         Callbacks for Embed                               *
  *                                                                           *
  *****************************************************************************/
 static void
-cb_net_start (GtkMozEmbed *embed, KzTabTree *tabtree)
+cb_net_start (KzEmbed *embed, KzTabTree *tabtree)
 {
 	GtkTreeIter *iter;
 	gchar *title;
 
-	g_return_if_fail(KZ_IS_MOZ_EMBED(embed));
+	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
-	title = kz_moz_embed_ensure_title(KZ_MOZ_EMBED(embed));
+	title = kz_embed_ensure_title(KZ_EMBED(embed));
 
-	iter = find_node (tabtree->store, KZ_MOZ_EMBED(embed));
+	iter = find_node (tabtree->store, KZ_EMBED(embed));
 	if (iter)
 	{
 		gtk_tree_store_set(tabtree->store, iter,
@@ -917,17 +917,17 @@ cb_net_start (GtkMozEmbed *embed, KzTabTree *tabtree)
 
 
 static void
-cb_net_stop (GtkMozEmbed *embed, KzTabTree *tabtree)
+cb_net_stop (KzEmbed *embed, KzTabTree *tabtree)
 {
 	GtkTreeIter *iter;
 	gchar *title;
 
-	g_return_if_fail(KZ_IS_MOZ_EMBED(embed));
+	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
-	title = kz_moz_embed_ensure_title(KZ_MOZ_EMBED(embed));
+	title = kz_embed_ensure_title(KZ_EMBED(embed));
 
-	iter = find_node (tabtree->store, KZ_MOZ_EMBED(embed));
+	iter = find_node (tabtree->store, KZ_EMBED(embed));
 	if (iter)
 	{
 		gtk_tree_store_set(tabtree->store, iter,
@@ -942,21 +942,21 @@ cb_net_stop (GtkMozEmbed *embed, KzTabTree *tabtree)
 
 
 static void
-cb_title_changed (GtkMozEmbed *embed, KzTabTree *tabtree)
+cb_title_changed (KzEmbed *embed, KzTabTree *tabtree)
 {
 	gchar *title;
 	GtkTreeIter *iter;
 
-	g_return_if_fail(KZ_IS_MOZ_EMBED(embed));
+	g_return_if_fail(KZ_IS_EMBED(embed));
 	g_return_if_fail(KZ_IS_TAB_TREE(tabtree));
 
-	title = kz_moz_embed_ensure_title(KZ_MOZ_EMBED(embed));
+	title = kz_embed_ensure_title(KZ_EMBED(embed));
 
-	iter = find_node (tabtree->store, KZ_MOZ_EMBED(embed));
+	iter = find_node (tabtree->store, KZ_EMBED(embed));
 	if (iter)
 	{
 		const gchar *color;
-		color = kz_moz_embed_is_loading(KZ_MOZ_EMBED(embed))
+		color = kz_embed_is_loading(KZ_EMBED(embed))
 			? LOADING_COLOR : NORMAL_COLOR;
 		gtk_tree_store_set(tabtree->store, iter,
 				   COLUMN_TITLE, title,
