@@ -28,8 +28,7 @@
 #include "kz-thumbnails-view.h"
 #include "kz-paned.h"
 #include "kz-tab-label.h"
-
-#define KZ_THUMBNAILS_SIDEBAR_TAB_BOOKMARK_KEY "KzThumbnailsSidebar::TabBookmark"
+#include "kz-proxy-folder.h"
 
 enum {
 	PROP_0,
@@ -57,16 +56,9 @@ static void     cb_paned_changed_position          (KzPaned *pane,
 						    KzThumbnailsView *view);
 static void	cb_thumbnail_activate		   (KzThumbnailsView *view,
 						    KzBookmark *bookmark,
+						    gint index,
 						    KzWindow *kz);
 
-#warning FIXME! We should create TabFolderBookmark Class?
-static void       connect_folder_signals         (KzBookmark     *folder,
-						  KzBookmark     *proxy);
-static void       disconnect_folder_signals      (KzBookmark     *folder,
-						  KzBookmark     *proxy);
-static KzBookmark *create_current_page_bookmark  (KzBookmark     *tab);
-static KzBookmark *create_proxy_folder           (KzBookmark     *tabs);
-
 static GtkWidget *kz_thumbnails_sidebar_closed_tabs_new 
 						   (KzSidebar *sidebar);
 #if 0
@@ -250,13 +242,11 @@ kz_thumbnails_sidebar_closed_tabs_new (KzSidebar *sidebar)
 	 * create a new bookmark folder which included each current page of  
 	 * closed tab.
 	 */
-	proxy = create_proxy_folder(sidebar->kz->closed_tabs);
-	
-	/* FIXME! these connections are leaks! */
-	connect_folder_signals(sidebar->kz->closed_tabs, proxy);
+	proxy = kz_proxy_folder_new(sidebar->kz->closed_tabs);
 	
 	kz_thumbnails_view_set_folder(KZ_THUMBNAILS_VIEW(tsidebar->view),
 				      proxy);
+	g_object_unref(proxy);
 
 	return GTK_WIDGET(tsidebar);
 }
@@ -299,156 +289,30 @@ cb_paned_changed_position (KzPaned *pane,
 }
 
 
-static KzBookmark *
-create_current_page_bookmark (KzBookmark *tab)
-{
-	KzBookmark *cur_page;
-	gint cur_pos;
-	GList *pages;
-	KzBookmark *new;
-
-	cur_pos = kz_bookmark_get_current(tab);
-
-	pages = kz_bookmark_get_children(tab);
-	cur_page = KZ_BOOKMARK(g_list_nth_data(pages, cur_pos));
-	g_list_free(pages);
-
-	new = kz_bookmark_new_with_attrs(kz_bookmark_get_title(cur_page),
-					 kz_bookmark_get_link(cur_page),
-					 NULL);
-	g_object_set_data(G_OBJECT(new),
-			  KZ_THUMBNAILS_SIDEBAR_TAB_BOOKMARK_KEY,
-			  tab);
-
-	return new;
-}
-
-
-static KzBookmark *
-create_proxy_folder (KzBookmark *tabs)
-{
-	GList *children, *node;
-	KzBookmark *ret_bookmark;
-	
-	children = kz_bookmark_get_children(tabs);
-	ret_bookmark = kz_bookmark_pure_folder_new();
-	
-	for (node = children; node; node = g_list_next(node))
-	{
-		KzBookmark *cur_page;
-		cur_page = create_current_page_bookmark(KZ_BOOKMARK(node->data));
-
-		kz_bookmark_append(ret_bookmark, cur_page);
-		g_object_unref(cur_page);
-	}
-
-	g_list_free(children);
-
-	return ret_bookmark;
-}
-
-
 static void
-cb_thumbnail_activate (KzThumbnailsView *view, KzBookmark *bookmark,
+cb_thumbnail_activate (KzThumbnailsView *view,
+		       KzBookmark *bookmark,
+		       gint index,
 		       KzWindow *kz)
 {
 	KzBookmark *tab;
 	GtkWidget *kzembed;
 	KzTabLabel *kztab;
+	GList *list;
 
 	g_return_if_fail(KZ_IS_BOOKMARK(bookmark));
 	g_return_if_fail(KZ_IS_WINDOW(kz));
 
-	tab = g_object_get_data(G_OBJECT(bookmark),
-				KZ_THUMBNAILS_SIDEBAR_TAB_BOOKMARK_KEY);
+	list = kz_bookmark_get_children(kz->closed_tabs);
+	tab = KZ_BOOKMARK(g_list_nth_data(list, index));
+	g_list_free(list);
 	g_return_if_fail(tab);
 
-	kzembed = kz_window_open_new_tab_at_tail(kz, NULL);
+	kzembed = kz_window_open_new_tab(kz, NULL);
 	kztab = KZ_TAB_LABEL(gtk_notebook_get_tab_label(
 			     GTK_NOTEBOOK(kz->notebook),
 			     kzembed));
 	kz_tab_label_set_history(KZ_TAB_LABEL(kztab), tab);
 
-	/* FIXME! should use parent bookmark */ 
 	kz_bookmark_remove(kz->closed_tabs, tab);
 }
-
-
-static gint
-find_proxy_item (gconstpointer a, gconstpointer b)
-{
-	const KzBookmark *bookmark1, *bookmark2 = b;
-
-	bookmark1 = g_object_get_data(G_OBJECT(a),
-				      KZ_THUMBNAILS_SIDEBAR_TAB_BOOKMARK_KEY);
-
-	return bookmark1 - bookmark2;
-}
-
-static void
-cb_folder_insert_child (KzBookmark *folder,
-			KzBookmark *child, KzBookmark *sibling,
-			KzBookmark *proxy)
-{
-	KzBookmark *new;
-	new = create_current_page_bookmark(child);
-
-	if (sibling)
-	{
-		GList *list, *node;
-
-		list = kz_bookmark_get_children(proxy);
-		node = g_list_find_custom(list, sibling, find_proxy_item);
-		if (node)
-		{
-			kz_bookmark_insert_before(proxy, new, 
-					          KZ_BOOKMARK(node->data));
-		}
-	}
-	else
-	{
-
-		kz_bookmark_prepend(proxy, new);
-	}
-	g_object_unref(new);
-}
-
-
-static void
-cb_folder_remove_child (KzBookmark *folder,
-			KzBookmark *child, KzBookmark *proxy) 
-{
-	GList *list, *node;
-
-	list = kz_bookmark_get_children(proxy);
-	node = g_list_find_custom(list, child, find_proxy_item);
-	g_return_if_fail(node);
-	
-	kz_bookmark_remove(proxy, KZ_BOOKMARK(node->data));
-}
-
-static void
-connect_folder_signals (KzBookmark *folder, KzBookmark *proxy)
-{
-	g_signal_connect_after(G_OBJECT(folder), "insert-child",
-			       G_CALLBACK(cb_folder_insert_child),
-			       proxy);
-	g_signal_connect_after(G_OBJECT(folder), "remove-child",
-			       G_CALLBACK(cb_folder_remove_child),
-			       proxy);
-}
-
-
-static void
-disconnect_folder_signals (KzBookmark *folder, KzBookmark *proxy)
-{
-	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(folder),
-		 G_CALLBACK(cb_folder_insert_child),
-		 proxy);
-	g_signal_handlers_disconnect_by_func
-		(G_OBJECT(folder),
-		 G_CALLBACK(cb_folder_remove_child),
-		 proxy);
-}
-
