@@ -25,26 +25,15 @@
 
 G_BEGIN_DECLS
 
-#if (GTK_MAJOR_VERSION == 2) && (GTK_MINOR_VERSION < 1)
-#  define gtkutil_notebook_get_n_pages(notebook) \
-   (GTK_IS_NOTEBOOK (notebook) ? g_list_length(GTK_NOTEBOOK(notebook)->children) : 0)
-#else /* (GTK_MAJOR_VERSION == 2) && (GTK_MAJOR_VERSION < 1) */
-#  define gtkutil_notebook_get_n_pages gtk_notebook_get_n_pages
-#endif /* (GTK_MAJOR_VERSION == 2) && (GTK_MAJOR_VERSION < 1) */
-
 void   gtkutil_menu_position_under_widget	(GtkMenu *menu,
 						 gint *x, gint *y,
 						 gboolean *push_in,
 						 gpointer user_data);
-
-GList *gtkutil_tree_selection_get_selected_rows	(GtkTreeSelection *selection,
-						 GtkTreeModel **model);
+#if 0
 GList *gtkutil_tree_selection_get_selected_references
 						(GtkTreeSelection *selection,
 						 GtkTreeModel **tree_model);
-void   gtkutil_list_store_swap			(GtkListStore *store,
-						 GtkTreeIter  *a,
-						 GtkTreeIter  *b);
+#endif
 void   gtkutil_copy_text                        (const gchar *text);
 void   gtkutil_append_im_menuitem               (GtkMenuShell *shell);
 
@@ -56,32 +45,28 @@ void   gtkutil_superpose_pixbuf                 (GtkWidget *widget,
 gboolean gtkutil_confirm_file_replace           (GtkWindow *parent,
 						 const gchar *filename);
 
-#define GTKUTIL_CREATE_MENU(menu, array, n_array, field)		\
-{									\
-	gint i;								\
-									\
-	menu = gtk_menu_new ();						\
-									\
-	for (i = 0; i < n_array; i++)					\
-	{								\
-		GtkWidget *item;					\
-									\
-		item = gtk_menu_item_new_with_label (_(array[i].field));\
-		gtk_menu_shell_append (GTK_MENU_SHELL(menu), item); 	\
-		gtk_widget_show (item);					\
-	}								\
+#define GTKUTIL_CREATE_MENU(combo, array, n_array, field)              \
+{								       \
+	guint i;                                                       \
+								       \
+	for (i = 0; i < (guint) n_array; i++)			       \
+	{                                                              \
+		gtk_combo_box_append_text(GTK_COMBO_BOX(combo),        \
+					  _(array[i].field));          \
+	}                                                              \
 }
 
 
 #define GTKUTIL_SET_DEFAULT_HISTORY(menu, str, array, n_array, field)	       \
 {									       \
-	gint i;								       \
+	guint i;							       \
 									       \
-	for (i = 0; str && i < n_array; i++)				       \
+	gtk_combo_box_set_active(GTK_COMBO_BOX(menu), 0);	               \
+	for (i = 0; str && i < (guint) n_array; i++)			       \
 	{								       \
 		if (!strcmp(str, array[i].field))			       \
 		{							       \
-			gtk_option_menu_set_history(GTK_OPTION_MENU(menu), i); \
+			gtk_combo_box_set_active(GTK_COMBO_BOX(menu), i);      \
 			break;						       \
 		}							       \
 	}								       \
