@@ -370,7 +370,7 @@ kz_entry_new (void)
 {
 	KzEntry *kzentry;
 
-	kzentry = KZ_ENTRY(g_object_new (KZ_TYPE_ENTRY, NULL));
+	kzentry = g_object_new (KZ_TYPE_ENTRY, NULL);
 
 	return GTK_WIDGET (kzentry);
 }
@@ -381,7 +381,7 @@ kz_entry_new_with_stock (const gchar *stock_id)
 {
 	KzEntry *kzentry;
 
-	kzentry = KZ_ENTRY(g_object_new (KZ_TYPE_ENTRY, NULL));
+	kzentry = g_object_new (KZ_TYPE_ENTRY, NULL);
 
 	return GTK_WIDGET (kzentry);
 }
