@@ -21,9 +21,9 @@
 #include "kz-thumbnail.h"
 
 #include <string.h>
+#include <glib/gi18n.h>
 #include "gobject-utils.h"
 #include "gtk-utils.h"
-#include "intl.h"
 #include "egg-pixbuf-thumbnail.h"
 
 /* object class */
@@ -62,7 +62,7 @@ kz_thumbnail_new (void)
 {
 	KzThumbnail *thumbnail;
 
-	thumbnail = KZ_THUMBNAIL(g_object_new (KZ_TYPE_THUMBNAIL, NULL));
+	thumbnail = g_object_new (KZ_TYPE_THUMBNAIL, NULL);
 
 	return GTK_WIDGET (thumbnail);
 }
